@@ -1,7 +1,7 @@
 /*
 *******************************************************************************
 *
-*   Copyright (C) 2005-2009, International Business Machines
+*   Copyright (C) 2005-2008, International Business Machines
 *   Corporation and others.  All Rights Reserved.
 *
 *******************************************************************************
@@ -225,7 +225,7 @@ _caseMap(const UCaseMap *csm, UCaseMapFull *map,
          int32_t srcStart, int32_t srcLimit,
          UErrorCode *pErrorCode) {
     const UChar *s;
-    UChar32 c, c2 = 0;
+    UChar32 c, c2;
     int32_t srcIndex, destIndex;
     int32_t locCache;
 
@@ -274,7 +274,7 @@ _toTitle(UCaseMap *csm,
     UText utext=UTEXT_INITIALIZER;
     const UChar *s;
     UChar32 c;
-    int32_t prev, titleStart, titleLimit, idx, destIndex, length;
+    int32_t prev, titleStart, titleLimit, index, destIndex, length;
     UBool isFirstIndex;
 
     utext_openUTF8(&utext, (const char *)src, srcLength, pErrorCode);
@@ -302,12 +302,12 @@ _toTitle(UCaseMap *csm,
         /* find next index where to titlecase */
         if(isFirstIndex) {
             isFirstIndex=FALSE;
-            idx=ubrk_first(csm->iter);
+            index=ubrk_first(csm->iter);
         } else {
-            idx=ubrk_next(csm->iter);
+            index=ubrk_next(csm->iter);
         }
-        if(idx==UBRK_DONE || idx>srcLength) {
-            idx=srcLength;
+        if(index==UBRK_DONE || index>srcLength) {
+            index=srcLength;
         }
 
         /*
@@ -323,22 +323,22 @@ _toTitle(UCaseMap *csm,
          * b) first case letter (titlecase)         [titleStart..titleLimit[
          * c) subsequent characters (lowercase)                 [titleLimit..index[
          */
-        if(prev<idx) {
+        if(prev<index) {
             /* find and copy uncased characters [prev..titleStart[ */
             titleStart=titleLimit=prev;
-            U8_NEXT(src, titleLimit, idx, c);
+            U8_NEXT(src, titleLimit, index, c);
             if((csm->options&U_TITLECASE_NO_BREAK_ADJUSTMENT)==0 && UCASE_NONE==ucase_getType(csm->csp, c)) {
                 /* Adjust the titlecasing index (titleStart) to the next cased character. */
                 for(;;) {
                     titleStart=titleLimit;
-                    if(titleLimit==idx) {
+                    if(titleLimit==index) {
                         /*
                          * only uncased characters in [prev..index[
                          * stop with titleStart==titleLimit==index
                          */
                         break;
                     }
-                    U8_NEXT(src, titleLimit, idx, c);
+                    U8_NEXT(src, titleLimit, index, c);
                     if(UCASE_NONE!=ucase_getType(csm->csp, c)) {
                         break; /* cased letter at [titleStart..titleLimit[ */
                     }
@@ -361,7 +361,7 @@ _toTitle(UCaseMap *csm,
 
                 
                 /* Special case Dutch IJ titlecasing */
-                if ( titleStart+1 < idx && 
+                if ( titleStart+1 < index && 
                      ucase_getCaseLocale(csm->locale,&csm->locCache) == UCASE_LOC_DUTCH &&
                      ( src[titleStart] == 0x0049 || src[titleStart] == 0x0069 ) &&
                      ( src[titleStart+1] == 0x004A || src[titleStart+1] == 0x006A )) { 
@@ -370,7 +370,7 @@ _toTitle(UCaseMap *csm,
                             titleLimit++;
                 }
                 /* lowercase [titleLimit..index[ */
-                if(titleLimit<idx) {
+                if(titleLimit<index) {
                     if((csm->options&U_TITLECASE_NO_LOWERCASE)==0) {
                         /* Normal operation: Lowercase the rest of the word. */
                         destIndex+=
@@ -378,11 +378,11 @@ _toTitle(UCaseMap *csm,
                                 csm, ucase_toFullLower,
                                 dest+destIndex, destCapacity-destIndex,
                                 src, csc,
-                                titleLimit, idx,
+                                titleLimit, index,
                                 pErrorCode);
                     } else {
                         /* Optionally just copy the rest of the word unchanged. */
-                        length=idx-titleLimit;
+                        length=index-titleLimit;
                         if((destIndex+length)<=destCapacity) {
                             uprv_memcpy(dest+destIndex, src+titleLimit, length);
                         }
@@ -392,7 +392,7 @@ _toTitle(UCaseMap *csm,
             }
         }
 
-        prev=idx;
+        prev=index;
     }
 
     if(destIndex>destCapacity) {
@@ -512,8 +512,7 @@ caseMap(const UCaseMap *csm,
             *pErrorCode=U_UNSUPPORTED_ERROR;
 #else
             /* UCaseMap is actually non-const in toTitle() APIs. */
-            UCaseMap *tmp = (UCaseMap *)csm;
-            destLength=_toTitle(tmp, dest, destCapacity,
+            destLength=_toTitle((UCaseMap *)csm, dest, destCapacity,
                                 src, &csc, srcLength,
                                 pErrorCode);
 #endif
