@@ -1,6 +1,6 @@
 /*
 *******************************************************************************
-* Copyright (C) 1997-2009, International Business Machines Corporation and    *
+* Copyright (C) 1997-2008, International Business Machines Corporation and    *
 * others. All Rights Reserved.                                                *
 *******************************************************************************
 *
@@ -33,8 +33,6 @@
 #include "unicode/ustring.h"
 #include "unicode/ucurr.h"
 #include "unicode/curramt.h"
-#include "unicode/numsys.h"
-#include "unicode/rbnf.h"
 #include "winnmfmt.h"
 #include "uresimp.h"
 #include "uhash.h"
@@ -74,17 +72,6 @@ static const UChar gLastResortPercentPat[] = {
 static const UChar gLastResortScientificPat[] = {
     0x23, 0x45, 0x30, 0 /* "#E0" */
 };
-static const UChar gLastResortIsoCurrencyPat[] = {
-    0xA4, 0xA4, 0x23, 0x30, 0x2E, 0x30, 0x30, 0x3B, 0x28, 0xA4, 0xA4, 0x23, 0x30, 0x2E, 0x30, 0x30, 0x29, 0 /* "\u00A4\u00A4#0.00;(\u00A4\u00A4#0.00)" */
-};
-static const UChar gLastResortPluralCurrencyPat[] = {
-    0x23, 0x30, 0x2E, 0x30, 0x30, 0xA0, 0xA4, 0xA4, 0xA4, 0 /* "#0.00\u00A0\u00A4\u00A4\u00A4*/
-};
-
-static const UChar gSingleCurrencySign[] = {0xA4, 0};
-static const UChar gDoubleCurrencySign[] = {0xA4, 0xA4, 0};
-
-static const UChar gSlash = 0x2f;
 
 // If the maximum base 10 exponent were 4, then the largest number would
 // be 99,999 which has 5 digits.
@@ -97,9 +84,7 @@ static const UChar * const gLastResortNumberPatterns[] =
     gLastResortDecimalPat,
     gLastResortCurrencyPat,
     gLastResortPercentPat,
-    gLastResortScientificPat,
-    gLastResortIsoCurrencyPat,
-    gLastResortPluralCurrencyPat,
+    gLastResortScientificPat
 };
 
 // *****************************************************************************
@@ -856,8 +841,6 @@ NumberFormat::makeInstance(const Locale& desiredLocale,
             // fall-through
 
         case kCurrencyStyle:
-        case kIsoCurrencyStyle: // do not support plural formatting here
-        case kPluralCurrencyStyle: 
             f = new Win32NumberFormat(desiredLocale, curr, status);
 
             if (U_SUCCESS(status)) {
@@ -878,8 +861,6 @@ NumberFormat::makeInstance(const Locale& desiredLocale,
     UnicodeString pattern;
     UResourceBundle *resource = ures_open((char *)0, desiredLocale.getName(), &status);
     UResourceBundle *numberPatterns = ures_getByKey(resource, DecimalFormat::fgNumberPatterns, NULL, &status);
-    NumberingSystem *ns = NULL;
-    UBool deleteSymbols = TRUE;
 
     if (U_FAILURE(status)) {
         // We don't appear to have resource data available -- use the last-resort data
@@ -893,7 +874,7 @@ NumberFormat::makeInstance(const Locale& desiredLocale,
     else {
         // If not all the styled patterns exists for the NumberFormat in this locale,
         // sets the status code to failure and returns nil.
-        if (ures_getSize(numberPatterns) < (int32_t)(sizeof(gLastResortNumberPatterns)/sizeof(gLastResortNumberPatterns[0])) -2 ) { //minus 2: ISO and plural 
+        if (ures_getSize(numberPatterns) < (int32_t)(sizeof(gLastResortNumberPatterns)/sizeof(gLastResortNumberPatterns[0]))) {
             status = U_INVALID_FORMAT_ERROR;
             goto cleanup;
         }
@@ -902,96 +883,29 @@ NumberFormat::makeInstance(const Locale& desiredLocale,
         symbolsToAdopt = new DecimalFormatSymbols(desiredLocale, status);
 
         int32_t patLen = 0;
-        
-        /* for ISOCURRENCYSTYLE and PLURALCURRENCYSTYLE,
-         * the pattern is the same as the pattern of CURRENCYSTYLE
-         * but by replacing the single currency sign with
-         * double currency sign or triple currency sign.
-         */
-        int styleInNumberPattern = ((style == kIsoCurrencyStyle || 
-                                     style == kPluralCurrencyStyle) ?
-                                    kCurrencyStyle : style);
-
-        const UChar *patResStr = ures_getStringByIndex(numberPatterns, (int32_t)styleInNumberPattern, &patLen, &status);
-       
+        const UChar *patResStr = ures_getStringByIndex(numberPatterns, (int32_t)style, &patLen, &status);
         // Creates the specified decimal format style of the desired locale.
         pattern.setTo(TRUE, patResStr, patLen);
     }
     if (U_FAILURE(status) || symbolsToAdopt == NULL) {
         goto cleanup;
     }
-    if(style==kCurrencyStyle || style == kIsoCurrencyStyle){
+    if(style==kCurrencyStyle){
         const UChar* currPattern = symbolsToAdopt->getCurrencyPattern();
         if(currPattern!=NULL){
             pattern.setTo(currPattern, u_strlen(currPattern));
         }
     }
-
-    ns = NumberingSystem::createInstance(desiredLocale,status);
-    
-    if (U_FAILURE(status)) {
+    f = new DecimalFormat(pattern, symbolsToAdopt, status);
+    if (U_FAILURE(status) || f == NULL) {
         goto cleanup;
     }
 
-    if (ns->isAlgorithmic()) {
-        UnicodeString nsDesc;
-        UnicodeString nsRuleSetGroup;
-        UnicodeString nsRuleSetName;
-        Locale nsLoc;
-        URBNFRuleSetTag desiredRulesType = URBNF_NUMBERING_SYSTEM;
-        
-        nsDesc.setTo(ns->getDescription());
-        int32_t firstSlash = nsDesc.indexOf(gSlash);
-        int32_t lastSlash = nsDesc.lastIndexOf(gSlash);
-        if ( lastSlash > firstSlash ) {
-            char nsLocID[ULOC_FULLNAME_CAPACITY];
-
-            nsDesc.extract(0,firstSlash,nsLocID,ULOC_FULLNAME_CAPACITY,US_INV);
-            nsRuleSetGroup.setTo(nsDesc,firstSlash+1,lastSlash-firstSlash-1);
-            nsRuleSetName.setTo(nsDesc,lastSlash+1);
-                      
-            nsLoc = Locale::createFromName(nsLocID);
-
-            UnicodeString SpelloutRules = UNICODE_STRING_SIMPLE("SpelloutRules");
-            if ( nsRuleSetGroup.compare(SpelloutRules) == 0 ) {
-                desiredRulesType = URBNF_SPELLOUT;
-            }
-        } else {
-            nsLoc = desiredLocale;
-            nsRuleSetName.setTo(nsDesc);
-        }
-
-        RuleBasedNumberFormat *r = new RuleBasedNumberFormat(desiredRulesType,nsLoc,status);
-
-        if (U_FAILURE(status) || r == NULL) {
-            goto cleanup;
-        }
-        r->setDefaultRuleSet(nsRuleSetName,status);
-        f = (NumberFormat *) r;
-
-    } else {
-        // replace single currency sign in the pattern with double currency sign
-        // if the style is kIsoCurrencyStyle
-        if (style == kIsoCurrencyStyle) {
-            pattern.findAndReplace(gSingleCurrencySign, gDoubleCurrencySign);
-        }
-
-        f = new DecimalFormat(pattern, symbolsToAdopt, style, status);
-        if (U_FAILURE(status) || f == NULL) {
-            goto cleanup;
-        }
-        deleteSymbols = FALSE;
-    }
-
     f->setLocaleIDs(ures_getLocaleByType(numberPatterns, ULOC_VALID_LOCALE, &status),
                     ures_getLocaleByType(numberPatterns, ULOC_ACTUAL_LOCALE, &status));
-
 cleanup:
     ures_close(numberPatterns);
     ures_close(resource);
-    if (ns) {
-       delete ns;
-    }
     if (U_FAILURE(status)) {
         /* If f exists, then it will delete the symbols */
         if (f==NULL) {
@@ -1006,9 +920,6 @@ cleanup:
         status = U_MEMORY_ALLOCATION_ERROR;
         f = NULL;
     }
-    if (deleteSymbols && symbolsToAdopt != NULL) {
-        delete symbolsToAdopt;
-    }
     return f;
 }
 
