@@ -401,8 +401,10 @@ uprv_init_pce(const struct UCollationElements *elems);
 #define UCOL_LAST_HAN_COMPAT  0xFA2F
 
 /* Han extension B is in plane 2 */
-#define UCOL_FIRST_HAN_B       0x20000
-#define UCOL_LAST_HAN_B        0x2A6DF
+#define UCOL_FIRST_HAN_B_LEAD  0xD840
+#define UCOL_FIRST_HAN_B_TRAIL 0xDC00
+#define UCOL_LAST_HAN_B_LEAD   0xD869
+#define UCOL_LAST_HAN_B_TRAIL  0xDEDF
 
 /* Hangul range */
 #define UCOL_FIRST_HANGUL 0xAC00
@@ -1064,7 +1066,13 @@ static inline UBool ucol_unsafeCP(UChar c, const UCollator *coll) {
 #endif /* XP_CPLUSPLUS */
 
 /* The offsetBuffer in collIterate might need to be freed to avoid memory leaks. */
-void ucol_freeOffsetBuffer(collIterate *s); 
+static void freeOffsetBuffer(collIterate *s) {
+    if (s != NULL && s->offsetBuffer != NULL) {
+        uprv_free(s->offsetBuffer);
+        s->offsetBuffer = NULL;
+        s->offsetBufferSize = 0;
+    }
+}
 
 
 #endif /* #if !UCONFIG_NO_COLLATION */
